@@ -1,7 +1,7 @@
 /*
  *  fetch.c
  *
- *  $Id: fetch.c,v 1.20 2006/01/20 15:58:34 source Exp $
+ *  $Id: fetch.c,v 1.24 2006/12/11 14:21:48 source Exp $
  *
  *  Fetch query result
  *
@@ -92,7 +92,7 @@
 #include <itrace.h>
 #include <unicode.h>
 
-static SQLRETURN
+SQLRETURN
 SQLFetch_Internal (SQLHSTMT hstmt)
 {
   STMT (pstmt, hstmt);
@@ -126,11 +126,10 @@ SQLFetch_Internal (SQLHSTMT hstmt)
       PUSHSQLERR (pstmt->herr, en_S1010);
       return SQL_ERROR;
     }
+
 #if (ODBCVER >= 0x0300)
-  if (((ENV_t *) ((DBC_t *) pstmt->hdbc)->henv)->dodbc_ver ==
-      SQL_OV_ODBC2
-      && ((GENV_t *) ((DBC_t *) pstmt->hdbc)->genv)->odbc_ver ==
-      SQL_OV_ODBC3)
+  if (((ENV_t *) ((DBC_t *) pstmt->hdbc)->henv)->dodbc_ver ==  SQL_OV_ODBC2
+      && ((GENV_t *) ((DBC_t *) pstmt->hdbc)->genv)->odbc_ver == SQL_OV_ODBC3)
     {				
 	/* 
 	 *  Try to map SQLFetch to SQLExtendedFetch for ODBC3 app calling 
@@ -140,9 +139,10 @@ SQLFetch_Internal (SQLHSTMT hstmt)
 	 *  requires it 
 	 */
       hproc = _iodbcdm_getproc (pstmt->hdbc, en_ExtendedFetch);
+
       if (hproc)
 	{
-	  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_ExtendedFetch,
+	  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
 	      (pstmt->dhstmt, SQL_FETCH_NEXT, 0, pstmt->rows_fetched_ptr,
 		  pstmt->row_status_ptr));
 	}
@@ -155,11 +155,10 @@ SQLFetch_Internal (SQLHSTMT hstmt)
       if (hproc == SQL_NULL_HPROC)
 	{
 	  PUSHSQLERR (pstmt->herr, en_IM001);
-
 	  return SQL_ERROR;
 	}
 
-      CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_Fetch,
+      CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
 	  (pstmt->dhstmt));
     }
 
@@ -230,7 +229,7 @@ SQLFetch (SQLHSTMT hstmt)
 
   retcode = SQLFetch_Internal (hstmt);
 
-  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+  if (SQL_SUCCEEDED (retcode))
     _iodbcdm_ConvBindData (pstmt);
 
   LEAVE_STMT (hstmt,
@@ -303,7 +302,7 @@ _iodbcdm_ExtendedFetch (
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_ExtendedFetch,
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
       (pstmt->dhstmt, fFetchType, irow, pcrow, rgfRowStatus));
 
   /* state transition */
@@ -369,7 +368,7 @@ SQLExtendedFetch (
   retcode =
       _iodbcdm_ExtendedFetch (hstmt, fFetchType, irow, pcrow, rgfRowStatus);
 
-  if (retcode == SQL_SUCCESS || retcode == SQL_SUCCESS_WITH_INFO)
+  if (SQL_SUCCEEDED (retcode))
     _iodbcdm_ConvBindData (pstmt);
 
   LEAVE_STMT (hstmt,
@@ -499,14 +498,6 @@ SQLGetData_Internal (
       return SQL_ERROR;
     }
 
-  /* call driver */
-  hproc = _iodbcdm_getproc (pstmt->hdbc, en_GetData);
-
-  if (hproc == SQL_NULL_HPROC)
-    {
-      PUSHSQLERR (pstmt->herr, en_IM001);
-      return SQL_ERROR;
-    }
 
   /*
    *  Convert C type to ODBC version of driver
@@ -519,7 +510,17 @@ SQLGetData_Internal (
       cbValueMax /= sizeof(wchar_t);
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_GetData,
+
+  /* call driver */
+  hproc = _iodbcdm_getproc (pstmt->hdbc, en_GetData);
+
+  if (hproc == SQL_NULL_HPROC)
+    {
+      PUSHSQLERR (pstmt->herr, en_IM001);
+      return SQL_ERROR;
+    }
+
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
       (pstmt->dhstmt, icol, nCType, rgbValue, cbValueMax, pcbValue));
 
   /* state transition */
@@ -647,7 +648,7 @@ SQLMoreResults_Internal (SQLHSTMT hstmt)
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_MoreResults,
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
       (pstmt->dhstmt));
 
   /* state transition */
@@ -814,7 +815,7 @@ _iodbcdm_SetPos (
       return SQL_ERROR;
     }
 
-  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc, en_SetPos,
+  CALL_DRIVER (pstmt->hdbc, pstmt, retcode, hproc,
       (pstmt->dhstmt, irow, fOption, fLock));
 
   /* state transition */
