@@ -1,7 +1,7 @@
 /*
  *  ithread.h
  *
- *  $Id: ithread.h,v 1.3 2006/01/20 15:58:35 source Exp $
+ *  $Id: ithread.h,v 1.4 2006/07/10 13:49:29 source Exp $
  *
  *  Macros for locking & multihreading
  *
@@ -122,7 +122,7 @@
 
 # define MUTEX_DECLARE(M)		pthread_mutex_t M
 # define MUTEX_INIT(M)			pthread_mutex_init (&M, NULL)
-# define MUTEX_DONE(M)			pthread_mutex_destroy (&M);
+# define MUTEX_DONE(M)			pthread_mutex_destroy (&M)
 # define MUTEX_LOCK(M)			pthread_mutex_lock(&M)
 # define MUTEX_UNLOCK(M)		pthread_mutex_unlock(&M)
 
