@@ -1,7 +1,7 @@
 /*
  *  result.c
  *
- *  $Id: result.c,v 1.28 2007/01/05 12:22:39 source Exp $
+ *  $Id: result.c,v 1.29 2007/10/08 12:37:15 source Exp $
  *
  *  Prepare for getting query result
  *
@@ -673,9 +673,10 @@ SQLDescribeCol_Internal (
     }
 
   /* call driver */
-
-  if ((penv->unicode_driver && waMode != 'W') 
-      || (!penv->unicode_driver && waMode == 'W'))
+    if (szColName != NULL && cbColNameMax > 0 && 
+    	((penv->unicode_driver && waMode != 'W') || 
+	(!penv->unicode_driver && waMode == 'W'))
+	)
     {
       if (waMode != 'W')
         {
@@ -984,8 +985,9 @@ SQLColAttributes_Internal (
     }
 
   /* call driver */
-  if ((penv->unicode_driver && waMode != 'W') 
-      || (!penv->unicode_driver && waMode == 'W'))
+  if (rgbDesc != NULL && cbDescMax > 0 && 
+      ((penv->unicode_driver && waMode != 'W') || 
+       (!penv->unicode_driver && waMode == 'W')))
     {
       switch(fDescType)
         {
