@@ -1,7 +1,7 @@
 /*
  *  trace.h
  *
- *  $Id: trace.h,v 1.3 2006/01/20 15:58:35 source Exp $
+ *  $Id: trace.h,v 1.4 2006/12/21 11:28:05 source Exp $
  *
  *  Trace functions
  *
@@ -101,8 +101,8 @@ extern "C" {
 /*
  *  Useful constants and macros
  */
-#define MAX_EMIT_STRING		4000		/* = 100 lines in output */
-#define MAX_EMIT_BINARY		1000		/* = 100 lines in output */
+#define MAX_EMIT_STRING		40000L		/* = 1000 lines in output */
+#define MAX_EMIT_BINARY		10000L		/* = 1000 lines in output */
 
 #define TRACE_ENTER	0
 #define TRACE_LEAVE	1
