@@ -1,11 +1,11 @@
 /*
  *  translator.c
  *
- *  $Id: translatorchooser.c,v 1.5 2005/03/14 10:35:43 source Exp $
+ *  $Id: translatorchooser.c,v 1.7 2007/02/02 11:58:14 source Exp $
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -14,6 +14,10 @@
  *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -26,8 +30,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +40,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -68,6 +72,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #include <sys/stat.h>
 #include <unistd.h>
 #include <time.h>
@@ -286,6 +291,10 @@ create_translatorchooser (HWND hwnd, TTRANSLATORCHOOSER *choose_t)
   gtk_window_set_modal (GTK_WINDOW (translatorchooser), TRUE);
   gtk_window_set_policy (GTK_WINDOW (translatorchooser), FALSE, FALSE, FALSE);
 
+#if GTK_CHECK_VERSION(2,0,0)
+  gtk_widget_show (translatorchooser);
+#endif
+
   dialog_vbox1 = GTK_DIALOG (translatorchooser)->vbox;
   gtk_object_set_data (GTK_OBJECT (translatorchooser), "dialog_vbox1",
       dialog_vbox1);
@@ -358,10 +367,18 @@ create_translatorchooser (HWND hwnd, TTRANSLATORCHOOSER *choose_t)
   gtk_widget_show (l_size);
   gtk_clist_set_column_widget (GTK_CLIST (clist1), 3, l_size);
 
+#if GTK_CHECK_VERSION(2,0,0)
+  style = gtk_widget_get_style (translatorchooser);
+  pixmap =
+      gdk_pixmap_create_from_xpm_d (translatorchooser->window, &mask,
+      &style->bg[GTK_STATE_NORMAL], (gchar **) img_xpm);
+#else
   style = gtk_widget_get_style (GTK_WIDGET (hwnd));
   pixmap =
       gdk_pixmap_create_from_xpm_d (GTK_WIDGET (hwnd)->window, &mask,
       &style->bg[GTK_STATE_NORMAL], (gchar **) img_xpm);
+#endif
+
   pixmap1 = gtk_pixmap_new (pixmap, mask);
   gtk_widget_ref (pixmap1);
   gtk_object_set_data_full (GTK_OBJECT (translatorchooser), "pixmap1",
