@@ -1,15 +1,13 @@
 /*
  *  SQLCreateDataSource.c
  *
- *  $Id: SQLCreateDataSource.c,v 1.12 2005/11/04 13:08:54 source Exp $
+ *  $Id: SQLCreateDataSource.c,v 1.14 2006/01/24 00:08:54 source Exp $
  *
  *  Add, modify or delete datasources
  *
  *  The iODBC driver manager.
  *
- *  The iODBC driver manager.
- *
- *  Copyright (C) 1999-2002 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -18,6 +16,10 @@
  *      - GNU Library General Public License (see LICENSE.LGPL)
  *      - The BSD License (see LICENSE.BSD).
  *
+ *  Note that the only valid version of the LGPL license as far as this
+ *  project is concerned is the original GNU Library General Public License
+ *  Version 2, dated June 1991.
+ *
  *  While not mandated by the BSD license, any patches you make to the
  *  iODBC source code may be contributed back into the iODBC project
  *  at your discretion. Contributions will benefit the Open Source and
@@ -30,8 +32,8 @@
  *  ============================================
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  License as published by the Free Software Foundation; only
+ *  Version 2 of the License dated June 1991.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,7 +42,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *
  *  The BSD License
@@ -72,6 +74,7 @@
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 #include <iodbc.h>
 #include <odbcinst.h>
 #include <iodbcadm.h>
@@ -100,7 +103,7 @@ extern BOOL ValidDSNW (LPCWSTR lpszDSN);
 	if ((handle = DLL_OPEN(path)) != NULL) \
 	{ \
 		if ((pDrvConnW = (pDrvConnWFunc)DLL_PROC(handle, "iodbcdm_drvconn_dialboxw")) != NULL) \
-		  pDrvConn(parent, dsn, sizeof(dsn) / sizeof(wchar_t), NULL, SQL_DRIVER_PROMPT, &config); \
+		  pDrvConnW(parent, dsn, sizeof(dsn) / sizeof(wchar_t), NULL, SQL_DRIVER_PROMPT, &config); \
       retcode = TRUE; \
 		DLL_CLOSE(handle); \
 	}
@@ -112,8 +115,8 @@ CreateDataSource (HWND parent, LPCSTR lpszDSN, SQLCHAR waMode)
   UWORD config = ODBC_USER_DSN;
   BOOL retcode = FALSE;
   void *handle;
-  pDrvConnFunc pDrvConn;
-  pDrvConnWFunc pDrvConnW;
+  pDrvConnFunc pDrvConn = NULL;
+  pDrvConnWFunc pDrvConnW = NULL;
 #if defined (__APPLE__) && !(defined (NO_FRAMEWORKS) || defined (_LP64))
   CFStringRef libname = NULL;
   CFBundleRef bundle;
